Page 75 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 75

Home

    payment of debts; ..." Article I, Section 10. The
    Constitution authorizes the Federal Government to "coin

    money" Article I, Section 8, but nowhere does it
    authorize the printing of money. The paper bills
    originally used in the United States were not recognized
    as money but were receipts for money and could be
    redeemed in silver or gold at any time.

    This kind of sound money helped to make the United
    States one of the greatest nations in the world. It also
    made it impossible for any central power to control the
    American people and herd them into a one world
    government. No doubt, this was one of the reasons that
    subversive forces went to work to destroy this element of

    For a deeper understanding of the importance of a
    sound monetary system, and why we must return to a
    sound system; we recommend John F. McManus' book
    Financial Terrorism: Hijacking America Under the
    Threat of Bankruptcy. It is available from Western
    Islands, P.O. Box 8040, Appleton, Wisconsin.

    70

    The Secret Side of History

    American independence.